% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gcn_inference.R
\name{module_enrichment}
\alias{module_enrichment}
\title{Perform enrichment analysis for coexpression network modules}
\usage{
module_enrichment(
  net = NULL,
  background_genes,
  annotation,
  column = NULL,
  correction = "BH",
  p = 0.05,
  bp_param = BiocParallel::SerialParam()
)
}
\arguments{
\item{net}{List object returned by \code{exp2gcn}.}

\item{background_genes}{Character vector of genes to be used as background
for the Fisher's Exact Test.}

\item{annotation}{Annotation data frame with genes in the first column
and functional annotation in the other columns. This data frame can
be exported from Biomart or similar databases.}

\item{column}{Column or columns of \code{annotation} to be used for enrichment.
Both character or numeric values with column indices can be used.
If users want to supply more than one column, input a character or
numeric vector. Default: all columns from \code{annotation}.}

\item{correction}{Multiple testing correction method. One of "holm",
"hochberg", "hommel", "bonferroni", "BH", "BY", "fdr" or "none".
Default is "BH".}

\item{p}{P-value threshold. P-values below this threshold will be considered
significant. Default is 0.05.}

\item{bp_param}{BiocParallel back-end to be used.
Default: BiocParallel::SerialParam()}
}
\value{
A data frame containing enriched terms, p-values, gene IDs
and module names.
}
\description{
Perform enrichment analysis for coexpression network modules
}
\examples{
\donttest{
data(filt.se)
data(zma.interpro)
background <- rownames(filt.se)
gcn <- exp2gcn(filt.se, SFTpower = 18, cor_method = "pearson")
mod_enrich <- module_enrichment(gcn, background, zma.interpro, p=1)
}
}
\author{
Fabricio Almeida-Silva
}
